RDFCalendar.FormatWriters.iCalendarWriter

Package RDFCalendar :: Module FormatWriters :: Class iCalendarWriter |
[show private | hide private]
[frames | no frames]

## Class iCalendarWriter

    An iCalendar writer class.

Method Summary
| ``__init__`(self, f, compact, use_quoted_printable, fold_incorrectly, do_not_fold)` Initialise the writer with a stream 'f', configuring the writer with the...
| `add_folded_lines(self, line, lines)`
| `close(self)`
| `end_element(self, label)`
| `get_folded_lines(self, value)`
| `start_element(self, label)`
| `write_attribute(self, name, modifiers, value, subvalues, multivalues)`

Method Details

### __init__(self, f, compact=0, use_quoted_printable=0, fold_incorrectly=0, do_not_fold=0) (Constructor)
    Initialise the writer with a stream 'f', configuring the writer with the
    following optional parameters:

      * compact              - use a compact representation (popular with
                               many applications, but not enabled by
                               default)
      * use_quoted_printable - use the quoted-printable representation for
                               text (not enabled by default)
      * fold_incorrectly     - produce incorrectly folded text to satisfy
                               non-compliant applications (not enabled by
                               default)
      * do_not_fold          - do not fold text but place long text on a
                               single line (not enabled by default)

Generated by Epydoc 2.1 on Tue Sep 18 23:33:17 2007 | http://epydoc.sf.net